// ########################################################################
// ## trigraphliste.h:                                                   ##
// ## Liste zusammenhngender, trivalenter Graphen                       ##
// ## Copyright Thomas Dreibholz, uzs6pq@ibm.rhrz.uni-bonn.de            ##
// ##           WWW Homepage:     http://ibm.rhrz.uni-bonn.de/~uzs6pq    ##
// ##           Arash Shahi,      shahi@xmailer.informatik.uni-bonn.de   ##
// ##           Jamshid Azizi,    azizi@xmailer.informatik.uni-bonn.de   ##
// ########################################################################

#ifndef TRIGRAPHLISTE_H
#define TRIGRAPHLISTE_H


#include <bool.h>


#include "einstellungen.h"
#include "trigraph.h"
#include "trigraph.icc"

   
// Klasse fr Liste von trivalenten Graphen
class TriGraphListe
{
   // ===== Konstruktoren und Destruktor ==================================
   public:
   TriGraphListe();
   TriGraphListe(const TriGraphListe& original);
   ~TriGraphListe();

   // ===== Zugriff auf Daten =============================================
   inline unsigned int Elemente() const;   
     

   // ===== Operatoren ====================================================
   void operator=(const TriGraphListe& original);
   friend ostream& operator<<(ostream& os, const TriGraphListe& liste);


   // ===== Bearbeitung der Liste =========================================
   void FuegeAnOhneVergleich(const TriGraph& t);
   bool FuegeAn(const TriGraph& t);
   bool Erster(TriGraph& t);
   bool Letzter(TriGraph& t);
   bool Nachfolger(TriGraph& t);

 
   // ===== Laden und Speichern ===========================================
   bool Lese(istream& is);
   bool Schreibe(ostream& os);
 
        
   // ===== Interne Variablen =============================================
   private:
   int       elemente;
   TriGraph* erster;
   TriGraph* aktueller;
   TriGraph* letzter;
      
   // ===== Interne Funktionen ============================================
   private:
   void Initialisiere();
   void GibFrei();
   void Clone(const TriGraphListe& original);
};
            
#endif                                                              
