// ########################################################################
// ## trigraphkatalog.h:                                                 ##
// ## Katalog von Listen zusammenhngender, trivalenter Graphen          ##
// ## Copyright Thomas Dreibholz, uzs6pq@ibm.rhrz.uni-bonn.de            ##
// ##           WWW Homepage:     http://ibm.rhrz.uni-bonn.de/~uzs6pq    ##
// ##           Arash Shahi,      shahi@xmailer.informatik.uni-bonn.de   ##
// ##           Jamshid Azizi,    azizi@xmailer.informatik.uni-bonn.de   ##
// ########################################################################

#ifndef TRIGRAPHKATALOG_H
#define TRIGRAPHKATALOG_H


#include <iostream.h>
#include <bool.h>

#include "einstellungen.h"
#include "trigraphliste.h"

   
// Klasse fr Katalog von trivalenten Graphen
class TriGraphKatalog
{
   // ===== Konstruktoren und Destruktor ==================================
   public:
   TriGraphKatalog();
   TriGraphKatalog(const unsigned int n);
   TriGraphKatalog(const TriGraphKatalog& original);
   ~TriGraphKatalog();


   // ===== Zugriff auf Daten =============================================
   inline unsigned int Eintraege() const;
   
   // ===== Operatoren ====================================================
   void operator=(const TriGraphKatalog& original);
   friend ostream& operator<<(ostream& os, const TriGraphKatalog& katalog);
   

   // ===== Bearbeitung des Kataloges =====================================
   void FuegeEinOhneVergleich(const TriGraph& t);              
   bool FuegeEin(const TriGraph& t);              
               
               
   // ===== Laden und Speichern ===========================================
   bool Lese(istream& is);
   bool Schreibe(ostream& os);         
         
         
   // ===== Interne Variablen =============================================
   private:
   unsigned int      knoten;    // Anzahl der Knoten der verwalteten Graphen
   unsigned int      eintraege; // Anzahl der Eintraege des Kataloges
   TriGraphListe**** liste;     // Der eigentliche Katalog
   unsigned int      maxEintrag[3];  // Obere Grenze pro Komponente der
                                     // Grad-Partition
      
   // ===== Interne Funktionen ============================================
   private:
   void Initialisiere(const unsigned int n);
   void GibFrei();
   void Clone(const TriGraphKatalog& original);
};

#endif                                                              
